import * as prompts from "@clack/prompts";
import chalk from "chalk";
import { lowerFirst } from "./lowerFirst.js";
const s = prompts.spinner();
function skipSpinnerBlock(blockText) {
  s.start(chalk.gray("\u2796 " + blockText));
  s.stop(chalk.gray("\u2796 " + blockText));
}
async function withSpinner(label, callback) {
  s.start(`${label}...`);
  try {
    const result = await callback();
    if (result === false) {
      s.stop(chalk.yellow(`\u26A0\uFE0F Error ${lowerFirst(label)}.`));
    } else {
      s.stop(chalk.green(`\u2705 Passed ${lowerFirst(label)}.`));
    }
    return result;
  } catch (error) {
    s.stop(chalk.red(`\u274C Error ${lowerFirst(label)}.`));
    throw new Error(`Failed ${lowerFirst(label)}`, { cause: error });
  }
}
export {
  skipSpinnerBlock,
  withSpinner
};
//# sourceMappingURL=spinners.js.map