import { parseArgs } from "node:util";
import { titleCase } from "title-case";
import { allArgOptions } from "./args.js";
import { runOrSkip } from "./cli/runOrSkip.js";
import { ensureRepositoryExists } from "./ensureRepositoryExists.js";
import { getOctokit } from "./getOctokit.js";
import { getPrefillOrPromptedValue } from "./getPrefillOrPromptedValue.js";
import { optionalDefault } from "./optionalDefault.js";
async function readInputs({
  args,
  defaults = {},
  overrides = {}
}) {
  const { values } = parseArgs({
    args,
    options: allArgOptions,
    strict: false,
    tokens: true
  });
  const owner = values.owner ?? await (overrides.owner?.() ?? await getPrefillOrPromptedValue(
    values.owner,
    "What owner or user will the repository be under?"
  ));
  const octokit = await runOrSkip(
    "Checking GitHub authentication",
    !!values["skip-github-api"],
    getOctokit
  );
  const repository = values.repository ?? await (overrides.repository?.() ?? ensureRepositoryExists(
    octokit,
    owner,
    await getPrefillOrPromptedValue(
      values.repository,
      "What will the kebab-case name of the repository be?"
    )
  ));
  const title = await getPrefillOrPromptedValue(
    values.title,
    "What will the Title Case title of the repository be?",
    titleCase(repository).replaceAll("-", " ")
  );
  const description = await getPrefillOrPromptedValue(
    values.description,
    "How would you describe the new package?",
    "A very lovely package. Hooray!"
  );
  return {
    octokit,
    values: {
      author: await optionalDefault(
        values.author,
        defaults.author
      ),
      description,
      email: await optionalDefault(
        values.email,
        defaults.email
      ),
      funding: await optionalDefault(
        values.funding,
        defaults.funding
      ),
      owner,
      releases: await optionalDefault(
        values.releases,
        defaults.releases
      ),
      repository,
      skipApi: !!values["skip-github-api"],
      skipContributors: !!values["skip-contributors"],
      skipInstall: !!values["skip-install"],
      skipRemoval: !!values["skip-removal"],
      skipRestore: values["skip-restore"],
      skipUninstall: !!values["skip-uninstall"],
      title,
      unitTests: await optionalDefault(
        values.unitTests,
        defaults.unitTests
      )
    }
  };
}
export {
  readInputs
};
//# sourceMappingURL=inputs.js.map